@@ -12,9 +12,9 @@ function(..., title=NULL, align="left",
   else if (reportFormat == "html") c("<!--", "-->")
   fncall <- paste(comment.char[1], paste(deparse(match.call()), collapse=" "), comment.char[2], "\n")
   
-  if (missing(font)) font <- get(".HTML.FONT.FONT.", envir=.GlobalEnv)
-  if (missing(family)) family <- get(".HTML.FONT.FAMILY.", envir=.GlobalEnv)
-  if (missing(size)) size <- get(".HTML.FONT.SIZE.", envir=.GlobalEnv)
+  if (missing(font)) font <- get("HTML.FONT.FONT", envir=options()$htmlCounters)
+  if (missing(family)) family <- get("HTML.FONT.FAMILY", envir=options()$htmlCounters)
+  if (missing(size)) size <- get("HTML.FONT.SIZE", envir=options()$htmlCounters)
   
   
   if (reportFormat == "latex"){
